@@ -37,6 +37,7 @@ log = logging.getLogger("braille")
 import signal
 import os
 
+from gi.repository import GLib
 from gi.repository import GObject
 GObject.threads_init()
 
@@ -1384,7 +1385,7 @@ def refresh(panToCursor=True,
             if attributeMask:
                 attributeMask += '\x00'
             writeStruct.regionSize += 1
-        writeStruct.text = substring
+        writeStruct.text = bytes(substring, 'UTF-8')
         writeStruct.cursor = cursorCell
 
         # [[[WDW - if you want to muck around with the dots on the
@@ -1403,7 +1404,7 @@ def refresh(panToCursor=True,
         #writeStruct.attrOr = myUnderline
 
         if attributeMask:
-            writeStruct.attrOr = attributeMask[startPos:endPos]
+            writeStruct.attrOr = bytes(attributeMask[startPos:endPos], 'UTF-8')
 
         if not _brlAPIRunning:
             init(_callback, settings.tty)
@@ -1478,7 +1479,7 @@ def resetFlashTimer():
     if _flashEventSourceId > 0:
         GObject.source_remove(_flashEventSourceId)
         flashTime = _saved[3]
-        _flashEventSourceId = GObject.timeout_add(flashTime, _flashCallback)
+        _flashEventSourceId = GLib.timeout_add(flashTime, _flashCallback)
 
 def _initFlash(flashTime):
     """Sets up the state needed to flash a message or clears any existing
@@ -1503,7 +1504,7 @@ def _initFlash(flashTime):
         _saved = (_lines, _regionWithFocus, viewport, flashTime)
 
     if flashTime > 0:
-        _flashEventSourceId = GObject.timeout_add(flashTime, _flashCallback)
+        _flashEventSourceId = GLib.timeout_add(flashTime, _flashCallback)
     elif flashTime < 0:
         _flashEventSourceId = -666
 
