@@ -27,30 +27,19 @@ __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import re
+import sys
 
-import acss
-import settings
-import speech
-import speechserver
-import orca
-import time
+from . import acss
+from . import settings
+from . import speech
+from . import speechserver
 
-desktopRunning = False
-try:
-    from gi.repository import Gdk
-    if Gdk.Display.get_default():
-        desktopRunning = True
-except:
-    pass
-
-from orca_i18n import _  # for gettext support
+from .orca_i18n import _
 
 workingFactories   = []
 speechServerChoice = None
 speechVoiceChoice  = None
 
-_settingsManager = getattr(orca, '_settingsManager')
-
 # Translators: this is a regular expression that is intended to match
 # a positive 'yes' response from a user at the command line.  The expression
 # as given means - does it begin with (that's the '^' character) any of
@@ -114,9 +103,9 @@ def sayAndPrint(text,
         speech.speak(text, voice)
 
     if getInput:
-        return raw_input(text)
+        return input(text)
     else:
-        print text
+        print(text)
 
 def setupSpeech(prefsDict):
     """Sets up speech support.  If speech setup is successful and the
@@ -139,7 +128,7 @@ def setupSpeech(prefsDict):
         # Translators: this means speech synthesis (i.e., the machine
         # speaks to you from its speakers) is not installed or working.
         #
-        print _("Speech is unavailable.")
+        print(_("Speech is unavailable."))
         return False
 
     try:
@@ -148,7 +137,7 @@ def setupSpeech(prefsDict):
         # Translators: this means speech synthesis (i.e., the machine
         # speaks to you from its speakers) is not installed or working.
         #
-        print _("Speech is unavailable.")
+        print(_("Speech is unavailable."))
         return False
 
     sayAndPrint(_("Welcome to Orca setup."))
@@ -166,7 +155,7 @@ def setupSpeech(prefsDict):
         # Translators: this means speech synthesis (i.e., the machine
         # speaks to you from its speakers) is not installed or working.
         #
-        print _("Speech is unavailable.")
+        print(_("Speech is unavailable."))
         return False
     elif len(workingFactories) > 1:
         # Translators: the speech system represents what general
@@ -489,15 +478,6 @@ def setupSpeech(prefsDict):
 
     return True
 
-def logoutUser():
-    """Log the user out of the desktop."""
-
-    import dbus
-    bus = dbus.SessionBus()
-    sessionManager = bus.get_object('org.gnome.SessionManager',
-                                    '/org/gnome/SessionManager')
-    sessionManager.Logout(dbus.types.UInt32(1))
-
 def showPreferencesUI(commandLineSettings):
     """Uses the console to query the user for Orca preferences."""
 
@@ -549,56 +529,13 @@ def showPreferencesUI(commandLineSettings):
 
     stop = True
 
-    _settingsManager.setFirstStart(False)
-
     # Sanity check for bug #642285
     #
-    if not prefsDict.has_key('profile'):
+    if 'profile' not in prefsDict:
         prefsDict['profile'] = settings.profile
 
-
-    logoutNeeded = _settingsManager.saveSettings(prefsDict, {}, {})
-    if logoutNeeded:
-        sayAndPrint(_("Accessibility support for GNOME has just been enabled."),
-                    logoutNeeded,
-                    False,
-                    speechServerChoice,
-                    speechVoiceChoice)
-        sayAndPrint( \
-        _("You need to log out and log back in for the change to take effect."),
-                    False,
-                    False,
-                    speechServerChoice,
-                    speechVoiceChoice)
-
-        if desktopRunning:
-            stop = True
-            while True:
-                answer = sayAndPrint( \
-                    _("Do you want to logout now?  Enter y or n: "),
-                                     False,
-                                     True,
-                                     speechServerChoice,
-                                     speechVoiceChoice)
-                try:
-                    if checkYes(answer):
-                        sayAndPrint(_("Setup complete. Logging out now."),
-                                    stop,
-                                    False,
-                                    speechServerChoice,
-                                    speechVoiceChoice)
-                        time.sleep(2)
-
-                        from gi.repository import GObject
-                        GObject.threads_init()
-                        GObject.idle_add(logoutUser)
-                    break
-                except:
-                    stop = False
-                    sayAndPrint(_("Please enter y or n."))
-
     answer = sayAndPrint(_("Setup complete.  Press Return to continue."),
-                         not logoutNeeded,
+                         True,
                          True,
                          speechServerChoice,
                          speechVoiceChoice)
@@ -607,7 +544,7 @@ def showPreferencesUI(commandLineSettings):
         factory.SpeechServer.shutdownActiveServers()
 
 def main():
-    showPreferencesUI()
+    showPreferencesUI(sys.argv[1:])
 
 if __name__ == "__main__":
     main()
