@@ -38,7 +38,7 @@ __author__    = "Tomas Cerha <cerha@brailcom.org>"
 __copyright__ = "Copyright (c) 2006-2008 Brailcom, o.p.s."
 __license__   = "LGPL"
 
-from gi.repository import GObject
+from gi.repository import GLib
 import re
 
 from . import chnames
@@ -257,6 +257,9 @@ class SpeechServer(speechserver.SpeechServer):
                 if current.get(acss_property) != value:
                     method(value)
                     current[acss_property] = value
+            elif acss_property == ACSS.AVERAGE_PITCH:
+                method(5.0)
+                current[acss_property] = 5.0
             elif acss_property == ACSS.FAMILY and current.get(acss_property) \
                     and acss == settings.voices[settings.DEFAULT_VOICE]:
                 # We need to explicitly reset (at least) the family.
@@ -312,6 +315,10 @@ class SpeechServer(speechserver.SpeechServer):
         if isinstance(text, ACSS):
             text = ''
         text = self.__addVerbalizedPunctuation(text)
+        if orca_state.activeScript and orca_state.usePronunciationDictionary:
+            text = orca_state.activeScript.\
+                utilities.adjustForPronunciation(text)
+
         # Replace no break space characters with plain spaces since some
         # synthesizers cannot handle them.  See bug #591734.
         #
@@ -348,9 +355,9 @@ class SpeechServer(speechserver.SpeechServer):
                         context.currentOffset = context.startOffset
                 elif t == speechserver.SayAllContext.COMPLETED:
                     context.currentOffset = context.endOffset
-                GObject.idle_add(orca_callback, context, t)
+                GLib.idle_add(orca_callback, context, t)
                 if t == speechserver.SayAllContext.COMPLETED:
-                    GObject.idle_add(self._say_all, iterator, orca_callback)
+                    GLib.idle_add(self._say_all, iterator, orca_callback)
             self._speak(context.utterance, acss, callback=callback,
                         event_types=list(self._CALLBACK_TYPE_MAP.keys()))
         return False # to indicate, that we don't want to be called again.
@@ -430,7 +437,7 @@ class SpeechServer(speechserver.SpeechServer):
                 self._speak(utterance, acss)
 
     def sayAll(self, utteranceIterator, progressCallback):
-        GObject.idle_add(self._say_all, utteranceIterator, progressCallback)
+        GLib.idle_add(self._say_all, utteranceIterator, progressCallback)
 
     def speakCharacter(self, character, acss=None):
         self._apply_acss(acss)
